# Django Ultimate Toolkit

The most useful tools for any django project

- Models
  - Mixins
    - TimeStampedModel
    - SoftDeleteModel
    - DBViewModel
    - MaterializedDBViewModel
  - Fields
    - CreatedAtField
    - UpdatedAtField
- Misc
  - Singleton 

